IF OBJECT_ID('TR__AssetItems__CircularParentCheck') IS NOT NULL DROP TRIGGER [TR__AssetItems__CircularParentCheck]
GO

CREATE TRIGGER [TR__AssetItems__CircularParentCheck]
ON [AssetItems] AFTER UPDATE, INSERT AS
BEGIN

	SET NOCOUNT ON

	DECLARE @AssetItems TABLE(
		[Base_AssetItem_Id] INT NOT NULL, 

		[Resolution_Depth] INT NOT NULL,
		[AssetItem_Id] INT NOT NULL, 
		[Parent_AssetItem_Id] INT NULL
	)

	DECLARE @depth INT, @row_count INT
	    SET @depth = 1
	    SET @row_count = 1 
	 
	INSERT INTO @AssetItems 
	  ([Base_AssetItem_Id], [Resolution_Depth], [AssetItem_Id], [Parent_AssetItem_Id])
	SELECT 
	   [AssetItem_Id], 1, [AssetItem_Id], [Parent_AssetItem_Id]
	  FROM [inserted] 
     

	WHILE @row_count > 0
	BEGIN 
		SET @depth = @depth + 1

		-- insert all of the previous depth's parents from the actual table
		INSERT INTO @AssetItems 
		  ([Base_AssetItem_Id], [Resolution_Depth], [AssetItem_Id], [Parent_AssetItem_Id])
		SELECT
		  [Base_AssetItem_Id], @depth, AG.[Parent_AssetItem_Id], PAG.[Parent_AssetItem_Id]
		FROM @AssetItems AG
	         INNER JOIN [AssetItems] PAG
		             ON PAG.[AssetItem_Id] = AG.[Parent_AssetItem_Id]
		WHERE AG.[Resolution_Depth] = @depth - 1

		SET @row_count = @@ROWCOUNT
	
		-- if an item is an ancestor of itself then shed tears
		IF EXISTS( SELECT * 
		             FROM [inserted] I
		                  INNER JOIN @AssetItems AG
		                          ON AG.[Resolution_Depth] > 1
		                         AND I.[AssetItem_Id] = AG.[Base_AssetItem_Id]
		                         AND I.[AssetItem_Id] = AG.[Parent_AssetItem_Id] )

		BEGIN 
				RAISERROR('The specified parent asset item ID will cause a cycle at depth %i, which is not supported.',16,2, @depth)
				ROLLBACK
				RETURN 
		END 

		-- sanity check
		IF @depth > 1000 BEGIN
				RAISERROR('Depth exceeded 1000.',16,1) 
				ROLLBACK
				RETURN 
		END 
	END 

END
GO