EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ProGetPackages_DeletePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a ProGet package.'
GO

IF OBJECT_ID('[ProGetPackages_DeletePackage]') IS NOT NULL DROP PROCEDURE [ProGetPackages_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ProGetPackages_DeletePackage]
(
	@Feed_Id INT,
	@Group_Name NVARCHAR(200),
	@Package_Name NVARCHAR(100),
	@Version_Text VARCHAR(255),
	@LatestVersion_Text VARCHAR(255)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @ProGetPackage_Id INT
		SET @ProGetPackage_Id = (SELECT [ProGetPackage_Id] FROM [ProGetPackages] WHERE [Feed_Id] = @Feed_Id AND [Group_Name] = @Group_Name AND [Package_Name] = @Package_Name)

		DELETE
		  FROM [ProGetPackageVersions]
		 WHERE [ProGetPackage_Id] = @ProGetPackage_Id
		   AND [Version_Text] = @Version_Text

		IF NOT EXISTS(SELECT * FROM [ProGetPackageVersions] WHERE [ProGetPackage_Id] = @ProGetPackage_Id)
		BEGIN

			DELETE
			  FROM [ProGetPackages]
			 WHERE [ProGetPackage_Id] = @ProGetPackage_Id

		END
		ELSE IF @LatestVersion_Text IS NOT NULL
		BEGIN

			UPDATE [ProGetPackages]
			   SET [LatestVersion_Text] = @LatestVersion_Text
			 WHERE [ProGetPackage_Id] = @ProGetPackage_Id

		END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ProGetPackages_DeletePackage] TO [ProGetUser_Role]
GO