EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Vulnerabilities_UpdateExternalVulnerability',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates vulnerabililty information based on data from an external source.'
GO

IF OBJECT_ID('[Vulnerabilities_UpdateExternalVulnerability]') IS NOT NULL DROP PROCEDURE [Vulnerabilities_UpdateExternalVulnerability]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Vulnerabilities_UpdateExternalVulnerability]
(
	@FeedType_Name VARCHAR(20),
	@External_Id VARCHAR(20),
	@Package_Name VARCHAR(200),
	@Package_Versions VARCHAR(200),
	@Title_Text NVARCHAR(200),
	@Description_Text NVARCHAR(MAX),
	@VulnerabilitySource_Id INT = NULL,
	@Blob_Digest VARCHAR(128),
	@Feed_Id int = NULL
)
AS
BEGIN

SET NOCOUNT ON

	DECLARE @Current_Vulnerability_Id INT
	DECLARE @Current_Package_Versions VARCHAR(200)
	DECLARE @Current_Title_Text NVARCHAR(200)
	DECLARE @Current_Description_Text NVARCHAR(MAX)

	SELECT @Current_Vulnerability_Id = [Vulnerability_Id],
	       @Current_Package_Versions = [Package_Versions],
		   @Current_Title_Text = [Title_Text],
		   @Current_Description_Text = [Description_Text]
	  FROM [Vulnerabilities]
	  WITH (UPDLOCK)
	 WHERE (
			(@VulnerabilitySource_Id IS NOT NULL AND [VulnerabilitySource_Id] = @VulnerabilitySource_Id) 
			OR (@Feed_Id IS NOT NULL AND [Feed_Id] = @Feed_Id)
		)
	   AND [External_Id] = @External_Id 
	   AND (
		(@Blob_Digest IS NOT NULL AND [Blob_Digest] = @Blob_Digest) 
		OR (@Package_Name IS NOT NULL AND [Package_Name] = @Package_Name)
	   )

	IF @Current_Vulnerability_Id IS NULL

		INSERT INTO [Vulnerabilities]
		(
			[FeedType_Name],
			[External_Id],
			[Package_Name],
			[Package_Versions],
			[Title_Text],
			[Description_Text],
			[VulnerabilitySource_Id],
			[Blob_Digest],
			[Feed_Id]
		)
		VALUES
		(
			@FeedType_Name,
			@External_Id,
			@Package_Name,
			@Package_Versions,
			@Title_Text,
			@Description_Text,
			@VulnerabilitySource_Id,
			@Blob_Digest,
			@Feed_Id
		)

	ELSE IF @Current_Package_Versions <> @Package_Versions OR @Current_Title_Text <> @Title_Text OR @Current_Description_Text <> @Description_Text

		UPDATE [Vulnerabilities]
		   SET [Package_Versions] = @Package_Versions,
		       [Title_Text] = COALESCE(@Title_Text, ''),
			   [Description_Text] = COALESCE(@Description_Text, '')
		 WHERE [Vulnerability_Id] = @Current_Vulnerability_Id

END
GO

GRANT EXECUTE ON [Vulnerabilities_UpdateExternalVulnerability] TO [ProGetUser_Role]
GO